@@ -66,7 +66,7 @@ class OpenIDConnect(flask_oidc.OpenIDConnect):
         if validity is True:
             token_info = self.token_data(token)
             if (not self.has_keycloak_role(keycloak_role, token_info, client=client) or
-                    not all(chk(token_info) for chk in checks)):
+                    not all(chk(token_info) for chk in checks or ())):
                 validity = 'Insufficient privileges.'
         return validity
 
